package org.blue.club.controller;

import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.tags.Tag;
import jakarta.servlet.http.HttpServletResponse;
import lombok.RequiredArgsConstructor;
import org.blue.club.annotation.Auth;
import org.blue.club.services.AvatarServices;
import org.mmga.spring.boot.starter.entities.Result;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

@RestController
@RequestMapping("/api/avatar")
@Tag(name = "头像相关接口")
@RequiredArgsConstructor
public class AvatarController {
    private final AvatarServices avatarServices;

    @GetMapping("/{sha1}")
    @Operation(description = "获取头像文件")
    public void getAvatar(HttpServletResponse response, @Schema(description = "头像文件SHA1值") @PathVariable("sha1") String sha1) {
        avatarServices.getAvatar(response, sha1);
    }

    @PostMapping("/upload")
    @Operation(description = "上传头像")
    @Auth
    public Result<String> changeAvatar(MultipartFile file) {
        return avatarServices.changeAvatar(file);
    }
}
