package org.blue.club.schedule;

import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.blue.club.dao.redis.AvatarOperationDao;
import org.blue.club.dao.redis.VerifyDao;
import org.blue.club.entities.vo.VerifyVo;
import org.blue.club.entities.vo.data.AvatarTmpVo;
import org.blue.club.utils.iop.FileUtils;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import java.io.File;
import java.time.Instant;
import java.time.temporal.ChronoUnit;
import java.util.Date;

@Slf4j
@Component
@RequiredArgsConstructor
public class RemoveExpireDataSchedule {
    private final AvatarOperationDao avatarDao;
    private final File tmpFolder;
    private final VerifyDao verifyDao;
    private final FileUtils fileUtils;

    @Scheduled(fixedDelay = 1000)
    public void removeTempAvatar() {
        Instant now = Instant.now();
        for (AvatarTmpVo avatarTmpVo : avatarDao.findAll()) {
            Date time = avatarTmpVo.createTime();
            Instant instant = time.toInstant();
            Instant expireTime = instant.plus(15, ChronoUnit.MINUTES);
            if (expireTime.isAfter(now)) {
                String s = avatarTmpVo.operationCode();
                File deleteFile = new File(tmpFolder, s);
                if (deleteFile.exists()) {
                    fileUtils.tryDeleteOrDeleteOnExit(deleteFile);
                }
                avatarDao.delete(avatarTmpVo);
            }
        }
    }

    @Scheduled(fixedDelay = 1000)
    public void removeExpiredVerify() {
        Instant now = Instant.now();
        for (VerifyVo verifyVo : verifyDao.findAll()) {
            Instant instant = verifyVo.createTime().toInstant();
            Instant expireTime = instant.plus(15, ChronoUnit.MINUTES);
            if (expireTime.isAfter(now)) {
                verifyDao.delete(verifyVo);
            }
        }
    }
}
